# KsManage
ksManage sdk is a support tool for ansible.kaytus.ksmanage

## External requirements

Circumstance instruction:
ksManage relies on the Ipmitool tool.

Main steps:
* pip install ksManage
* yum install ipmitool